/*=========================================================================

  Program:   Visualization Toolkit
  Module:    $RCSfile: vtkSimple3DCirclesStrategy.h,v $

  Copyright (c) Ferenc Nasztanovics
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
#ifndef vtkSimple3DCirclesStrategyH
#define vtkSimple3DCirclesStrategyH 1

#include "vtkGraphLayoutStrategy.h"
#include "vtkIntArray.h"

#include <vtkstd/list>

class vtkDirectedGraph;
class vtkIdTypeArray;

class VTK_INFOVIS_EXPORT vtkSimple3DCirclesStrategy : public vtkGraphLayoutStrategy
{
public:
	static vtkSimple3DCirclesStrategy * New();
	vtkTypeRevisionMacro(vtkSimple3DCirclesStrategy,vtkGraphLayoutStrategy);
	void PrintSelf( ostream& os, vtkIndent indent );

//BTX
	enum
	{
		FixedRadiusMethod, FixedDistanceMethod
	};
//ETX

	vtkSetMacro(Radius,double);
	vtkGetMacro(Radius,double);
	vtkSetMacro(Height,double);
	vtkGetMacro(Height,double);
	vtkSetVector3Macro(Orign,double);
	vtkGetVector3Macro(Orign,double);
	vtkSetVector3Macro(Direction,double);
	vtkGetVector3Macro(Direction,double);
	vtkSetMacro(Method,int);
	vtkGetMacro(Method,int);
	vtkSetObjectMacro(MarkedStartPoints,vtkIntArray);
	vtkGetObjectMacro(MarkedStartPoints,vtkIntArray);
	vtkSetMacro(MarkedValue,int);
	vtkGetMacro(MarkedValue,int);
	vtkSetMacro(ForceToUseUniversalStartPointsFinder,bool);
	vtkGetMacro(ForceToUseUniversalStartPointsFinder,bool);
	vtkBooleanMacro(ForceToUseUniversalStartPointsFinder,bool);

	virtual void Layout( void );
protected:
	vtkSimple3DCirclesStrategy( void );
	virtual ~vtkSimple3DCirclesStrategy( void );
//BTX
	typedef std::list<vtkIdType> vtkStartStore;
	virtual int UniversalStartPoints( vtkDirectedGraph * input, vtkStartStore &target, vtkIntArray * layers );
	virtual int BuildLayers( vtkDirectedGraph * input, vtkStartStore &source, vtkIntArray * layers );
	virtual void BuildPointOrder( vtkDirectedGraph * input, vtkStartStore &source, vtkIntArray * layers, vtkIdTypeArray * order );
//ETX

	double Radius;
	double Height;
	double Orign[3];
	double Direction[3];
	int Method;
	vtkIntArray * MarkedStartPoints;
	int MarkedValue;
	bool ForceToUseUniversalStartPointsFinder;
private:
	vtkSimple3DCirclesStrategy(const vtkSimple3DCirclesStrategy&);  // Not implemented.
	void operator=(const vtkSimple3DCirclesStrategy&);  // Not implemented.
};

#endif
