/*=========================================================================

  Program:   Visualization Toolkit
  Module:    $RCSfile: QVTKOutputWindow.cxx,v $

  Copyright (c) Ferenc Nasztanovics
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
#include "QVTKOutputWindow.h"

#include <QSettings>
#include <QVBoxLayout>

#include "vtkOutputWindow.h"
#include "vtkSmartPointer.h"

#include "vtkQtOutputWindow.h"
#include "vtkQtOutTextWidget.h"

QVTKOutputWindow::QVTKOutputWindow( QWidget * parent, Qt::WindowFlags f )
: QDialog( parent, f ), ShowOnLogAdded(false), original(0), qtbased(0), sets( new QSettings )
{
	this->setObjectName( "QVTKOutputWindow" );
	this->resize(400, 300);
	this->setWindowTitle( "VTK output" );

	QVBoxLayout * verticalLayout = new QVBoxLayout(this);
	verticalLayout->setObjectName( "verticalLayout" );

	vtkQtOutTextWidget * plainVTKOut = new vtkQtOutTextWidget(this);
	plainVTKOut->setReadOnly( true );

	plainVTKOut->setObjectName( "plainVTKOut" );
	verticalLayout->addWidget( plainVTKOut );

	connect( plainVTKOut, SIGNAL(textChanged()), this, SLOT(textChanged()) );

	this->original = vtkOutputWindow::GetInstance();
	this->original->Register(NULL);

	this->qtbased = vtkQtOutputWindow::New();

	this->qtbased->SetTextEditTarget( plainVTKOut );

	vtkOutputWindow::SetInstance( this->qtbased );

	this->restoreGeometry( this->sets->value( "Windows/QVTKOutputWindow/Geometry", this->saveGeometry() ).toByteArray() );
}

QVTKOutputWindow::~QVTKOutputWindow( void )
{
	if ( this->original != 0 )
	{
		if ( vtkOutputWindow::GetInstance() == this->qtbased )
		{
			vtkOutputWindow::SetInstance( this->original );
		}
		this->original->Delete();
		this->original = 0;
	}
	if ( this->qtbased != 0 )
	{
		this->qtbased->Delete();
		this->qtbased = 0;
	}
	if ( this->sets != 0 )
	{
		this->sets->setValue( "Windows/QVTKOutputWindow/Geometry", this->saveGeometry() );
		delete this->sets;
		this->sets = 0;
	}
}

bool QVTKOutputWindow::isShowOnLogAdded( void )
{
	return this->ShowOnLogAdded;
}

void QVTKOutputWindow::setShowOnLogAdded( bool Value )
{
	if ( this->ShowOnLogAdded != Value )
	{
		this->ShowOnLogAdded = Value;

		if ( this->ShowOnLogAdded )
			connect( this->qtbased->GetTextEditTarget(), SIGNAL(textChanged()), this, SLOT(show()) );
		else
			disconnect( this->qtbased->GetTextEditTarget(), SIGNAL(textChanged()), this, SLOT(show()) );
	}
}

void QVTKOutputWindow::textChanged( void )
{
	emit LogAdded();
}
