/*=========================================================================

  Program:   Visualization Toolkit
  Module:    $RCSfile: vtkQtOutTextWidget.cxx,v $

  Copyright (c) Ferenc Nasztanovics
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
#include "vtkQtOutTextWidget.h"

#include <QMutex>
#include <QMutexLocker>
#include <QString>

vtkQtOutTextWidget::vtkQtOutTextWidget( QWidget * parent )
: QVTK_VTK_OUT_WIDGET_BASE( parent ), mutex( new QMutex )
{
}

vtkQtOutTextWidget::vtkQtOutTextWidget( const QString & text, QWidget * parent )
: QVTK_VTK_OUT_WIDGET_BASE( text, parent ), mutex( new QMutex )
{
}

vtkQtOutTextWidget::~vtkQtOutTextWidget( void )
{
	if ( this->mutex != 0 )
	{
		delete this->mutex;
		this->mutex = 0;
	}
}

void vtkQtOutTextWidget::DisplayText( const char * text )
{
	QMutexLocker locker( this->mutex );
	if ( text == 0 )
		return;
	QString stext( text );
#if QT_VERSION >= 0x040400
	this->appendPlainText( stext );
#else
	this->append( stext );
#endif
}

void vtkQtOutTextWidget::DisplayText( const QString & text )
{
	QMutexLocker locker( this->mutex );
	if ( text.isEmpty() )
		return;
#if QT_VERSION >= 0x040400
	this->appendPlainText( text );
#else
	this->append( text );
#endif
}
