/*=========================================================================

  Program:   Visualization Toolkit
  Module:    $RCSfile: vtkQtOutputWindow.cxx,v $

  Copyright (c) Ferenc Nasztanovics
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
#include "vtkQtOutputWindow.h"

#include "vtkObjectFactory.h"

#include "vtkQtOutTextWidget.h"
#include <QMessageBox>
#include <QString>

vtkStandardNewMacro(vtkQtOutputWindow);
vtkCxxRevisionMacro(vtkQtOutputWindow, "$Revision: 0.1 $");

void vtkQtOutputWindow::PrintSelf( ostream& os, vtkIndent indent )
{
	this->Superclass::PrintSelf( os, indent );
	os << indent << "Output display Qt class base type is: QVTK_VTK_OUT_WIDGET_BASE" << endl;
	if ( this->TextEditTarget != 0 )
		os << indent << "Output display Qt class name is: " << this->TextEditTarget->objectName().toStdString() << endl;
	else
		os << indent << "Output display Qt class name is: NULL" << endl;
}

void vtkQtOutputWindow::DisplayText( const char * text )
{
	if ( text == 0 )
		return;

	if ( this->SendToStdErr )
		cerr << text << endl;

	if ( this->PromptUser )
	{
		if ( QMessageBox::critical( this->TextEditTarget, "Error", QString(text) + QString("\nPress Cancel to suppress any further messages."), QMessageBox::Ok | QMessageBox::Cancel ) == QMessageBox::Cancel )
		{
			vtkObject::GlobalWarningDisplayOff();
		}
		return;
	}

	if ( this->TextEditTarget != 0 )
		this->TextEditTarget->DisplayText( text );
}

vtkQtOutputWindow::vtkQtOutputWindow( void )
: TextEditTarget(0)
{
	if ( getenv( "DART_TEST_FROM_DART" ) )
	{
		this->SendToStdErr = true;
	}
	else
	{
		this->SendToStdErr = false;
	}
}

vtkQtOutputWindow::~vtkQtOutputWindow( void )
{
}
